@@ -128,7 +128,7 @@ LANG_ALTS = frozenset(
 re_xml_illegal_chars = re.compile(
     r"(?u)[^\x09\x0A\x0D\x20-\U0000D7FF\U0000E000-\U0000FFFD\U00010000-\U0010FFFF]"
 )
-re_xml_illegal_bytes = re.compile(br"[^\x09\x0A\x0D\x20-\xFF]|&#0;")
+re_xml_illegal_bytes = re.compile(rb"[^\x09\x0A\x0D\x20-\xFF]|&#0;")
 
 # Might want to check re_xml_illegal_bytes for patterns such as:
 # br"&#(?:[0-9]|0[0-9]|1[0-9]|2[0-9]|3[0-1]
@@ -221,10 +221,18 @@ def decode_pdf_date(s: str) -> datetime:
     elif s.endswith('Z'):
         s = s.replace('Z', '+0000')
     s = s.replace("'", "")  # Remove apos from PDF time strings
-    try:
-        return datetime.strptime(s, r'%Y%m%d%H%M%S%z')
-    except ValueError:
-        return datetime.strptime(s, r'%Y%m%d%H%M%S')
+
+    date_formats = [
+        r"%Y%m%d%H%M%S%z",  # Format with timezone
+        r"%Y%m%d%H%M%S",    # Format without timezone
+        r"%Y%m%d",          # Date only format
+    ]
+    for date_format in date_formats:
+        try:
+            return datetime.strptime(s, date_format)
+        except ValueError:
+            continue
+    raise ValueError(f"Date string does not match any known format: {s}")
 
 
 class Converter(ABC):
@@ -462,9 +470,7 @@ class PdfMetadata(MutableMapping):
             try:
                 self._xmp = parser(data)
             except (
-                XMLSyntaxError
-                if self.overwrite_invalid_xml
-                else NeverRaise  # type: ignore
+                XMLSyntaxError if self.overwrite_invalid_xml else NeverRaise  # type: ignore
             ) as e:
                 if str(e).startswith("Start tag expected, '<' not found") or str(
                     e
